@@ -3,6 +3,9 @@
 from asyncify._meta import __version__
 from asyncify.core import (
     ANYIO,
+    aiorun,
+    aiorun_anyio,
+    aiorun_asyncio,
     aiterable,
     anyio_asyncify,
     anyio_run,
@@ -19,6 +22,9 @@ __all__ = (
     "ANYIO",
     "__version__",
     "aiterable",
+    "aiorun",
+    "aiorun_anyio",
+    "aiorun_asyncio",
     "anyio_asyncify",
     "anyio_run",
     "asyncify",
